#
# spec file for package fetchmsttfonts
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2020 B1 Systems GmbH
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fetchmsttfonts
Version:        12.0
Release:        1.13
Summary:        Helper package to download Microsoft Core fonts for the Web
License:        GPL-2.0-or-later
Group:          System/X11/Fonts
URL:            https://corefonts.sourceforge.net/
Source0:        fetchmsttfonts.sh.in
Source1:        COPYING
Source4:        corefonts.sha512
#these stop the patch from pulling in the package
#Provides:       pullin-msttf-fonts = 11.1
#Obsoletes:      pullin-msttf-fonts <= 11.1
Requires:       cabextract
Requires:       coreutils
Requires:       curl
Requires:       fonts-config
Requires:       mktemp
Requires:       w3m
BuildArch:      noarch

%description
This package contains a helper script that downloads and installs
a number of TrueType fonts collectively known as corefonts, or the
Core fonts for the Web. Originally made available my Micosoft under
a non-free End-user licence agreement (EULA), they continue to be
distributed subject to the same licence terms. The user is shown
a copy of the licence text upon execution.

The Core fonts for the Web include: Arial, Arial Black, Andale Mono,
Monotype, Courier New, Comic Sans MS, Georgia, Impact, Times New
Roman, Trebuchet MS, Verdana, Webdings.

%prep
cp %{SOURCE0} .
cp %{SOURCE1} .
cp %{SOURCE4} .

%build
sed \
	-e 's,__VERSION__,%version,' \
	-e 's,__RELEASE__,%release,' \
	-e 's,__NAME__,%name,' \
	fetchmsttfonts.sh.in > fetchmsttfonts.sh

%install
%suse_install_update_script fetchmsttfonts.sh
%{nil}
#
mkdir -p %buildroot/var/adm/update-messages
touch %buildroot/var/adm/update-messages/%name-%version-%release-1
mkdir -p %buildroot/usr/share/doc/corefonts
touch %buildroot/usr/share/doc/corefonts/EULA.html
mkdir -p %buildroot/usr/share/fonts/truetype
for f in webdings.ttf verdanaz.ttf verdana.ttf verdanai.ttf verdanab.ttf trebuc.ttf trebucit.ttf trebucbi.ttf trebucbd.ttf times.ttf timesi.ttf timesbi.ttf timesbd.ttf impact.ttf georgiaz.ttf georgia.ttf georgiai.ttf georgiab.ttf cour.ttf couri.ttf courbi.ttf courbd.ttf comic.ttf comicbd.ttf ariblk.ttf arial.ttf ariali.ttf arialbi.ttf arialbd.ttf andalemo.ttf;
do
	touch %buildroot/usr/share/fonts/truetype/$f
done
mkdir -p %{buildroot}/usr/share/%{name}
mv corefonts.sha512 %{buildroot}/usr/share/%{name}

%postun -p /usr/sbin/fonts-config

%files
%license COPYING
/var/adm/update-scripts/*
%dir /usr/share/doc/corefonts
%dir /usr/share/fonts/truetype
%ghost /var/adm/update-messages/%name-%version-%release-1
# so we can get rid of them by rpm -e fetchmsttfonts
%ghost /usr/share/doc/corefonts/EULA.html
%ghost /usr/share/fonts/truetype/webdings.ttf
%ghost /usr/share/fonts/truetype/verdanaz.ttf
%ghost /usr/share/fonts/truetype/verdana.ttf
%ghost /usr/share/fonts/truetype/verdanai.ttf
%ghost /usr/share/fonts/truetype/verdanab.ttf
%ghost /usr/share/fonts/truetype/trebuc.ttf
%ghost /usr/share/fonts/truetype/trebucit.ttf
%ghost /usr/share/fonts/truetype/trebucbi.ttf
%ghost /usr/share/fonts/truetype/trebucbd.ttf
%ghost /usr/share/fonts/truetype/times.ttf
%ghost /usr/share/fonts/truetype/timesi.ttf
%ghost /usr/share/fonts/truetype/timesbi.ttf
%ghost /usr/share/fonts/truetype/timesbd.ttf
%ghost /usr/share/fonts/truetype/impact.ttf
%ghost /usr/share/fonts/truetype/georgiaz.ttf
%ghost /usr/share/fonts/truetype/georgia.ttf
%ghost /usr/share/fonts/truetype/georgiai.ttf
%ghost /usr/share/fonts/truetype/georgiab.ttf
%ghost /usr/share/fonts/truetype/cour.ttf
%ghost /usr/share/fonts/truetype/couri.ttf
%ghost /usr/share/fonts/truetype/courbi.ttf
%ghost /usr/share/fonts/truetype/courbd.ttf
%ghost /usr/share/fonts/truetype/comic.ttf
%ghost /usr/share/fonts/truetype/comicbd.ttf
%ghost /usr/share/fonts/truetype/ariblk.ttf
%ghost /usr/share/fonts/truetype/arial.ttf
%ghost /usr/share/fonts/truetype/ariali.ttf
%ghost /usr/share/fonts/truetype/arialbi.ttf
%ghost /usr/share/fonts/truetype/arialbd.ttf
%ghost /usr/share/fonts/truetype/andalemo.ttf
/usr/share/%{name}

%changelog
* Sat Dec 12 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- if the fonts are already present, just skip the download. These
  fonts are not going to change, besides we ar checking for a
  specific version (shasum) anyway
- bump version by one to indicate this change of behaviour
- get rid of awk dependency
* Wed Dec  2 2020 Andreas Stieger <andreas.stieger@gmx.de>
- When using rpm --excludedocs (rpm.install.excludedocs = yes),
  the script would fail boo#1096305
* Fri Jan  3 2020 Andreas Stieger <andreas.stieger@gmx.de>
- improve package description for discoverability (boo#1160070)
* Fri Aug 11 2017 9@cirno.systems
- Remove unnecessary BuildRequires
- Refactor download script
  * Use sf.net automatic mirror selection
  * Remove proxy settings code as it is already applied as part of
    openSUSE’s default /etc/profile.sh
  * Fix some issues pointed out by shellcheck
* Thu Dec 10 2015 astieger@suse.com
- verify md5 and sha1 checksums (sourced from upstream),
  SHA-512 checksums (generated locally) boo#958651
- no longer download the Andale file twice
- update license text for new FSF address
* Mon May 11 2015 meissner@suse.com
- remove voxel from server list (gone) bsc#930338
* Sat Nov 15 2014 Led <ledest@gmail.com>
- fix bashisms in fetchmsttfonts.sh script
* Wed Sep 19 2012 meissner@suse.com
- /etc/sysconfig/proxy could be missing bnc#777151
* Fri Dec  9 2011 meissner@suse.de
- post (and display) EULA.html to text as post-install message.
* Wed Oct 19 2011 jdelvare@suse.de
- Drop references to legacy package agfa-fonts.
- Properly reference all files and directories so that they are
  deleted on package removal.
* Mon Aug  8 2011 meissner@suse.de
- Add COPYING file bnc#656777
* Wed Mar  9 2011 meissner@suse.de
- 11.4 submission
* Tue Jul 13 2010 dmueller@suse.de
- submission for 11.3 (bnc#621540)
* Fri Jun 18 2010 dmueller@suse.de
- bump version to 11.3
* Tue Oct 13 2009 meissner@suse.de
- fixed to use new sourceforge download URLs. bnc#533112, bnc#546461
* Wed Jan 28 2009 meissner@suse.de
- %%ghost the font files so they get removed on -e
- run font-config on %%postun (for removal), buildrequire it and
  freetype2 for it.
* Wed Dec 17 2008 meissner@suse.de
- exit 0 when we are running non-chrooted (oS 11.1 bug in some
  installation methods) bnc#456795
* Fri Dec  5 2008 meissner@suse.de
- require coreutils (for /usr/bin/id) and fonts-config
  for minimal builds. bnc#456795
* Mon Dec  1 2008 ro@suse.de
- insert newline after macro to help macro expansion ...
* Sun Nov 30 2008 coolo@suse.de
- according to my test case, it works if there is no provides/obsoletes
  to the old name
* Fri Nov 28 2008 meissner@suse.de
- reviewed and adjusted server list. Some servers no longer
  carried the fonts.
* Fri Nov 28 2008 dmueller@suse.de
- update for 11.1
  * add eula to package
* Tue Jun 24 2008 meissner@suse.de
- initial package
  - included fetchmsttfonts.sh script from 10.3
